/*
 * Copyright (C) 2016-2016 52°North Initiative for Geospatial Open Source
 * Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 as published
 * by the Free Software Foundation.
 *
 * If the program is linked with libraries which are licensed under one of
 * the following licenses, the combination of the program with the linked
 * library is not considered a "derivative work" of the program:
 *
 *     - Apache License, version 2.0
 *     - Apache Software License, version 1.0
 *     - GNU Lesser General Public License, version 3
 *     - Mozilla Public License, versions 1.0, 1.1 and 2.0
 *     - Common Development and Distribution License (CDDL), version 1.0
 *
 * Therefore the distribution of the program linked with libraries licensed
 * under the aforementioned licenses, is permitted by the copyright holders
 * if the distribution is compliant with both the GNU General Public
 * License version 2 and the aforementioned licenses.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
 * Public License for more details.
 */
package org.n52.subverse.subscription;

import com.google.common.base.Objects;
import java.io.Serializable;

public class Subscription implements Serializable {

    private final String id;
    private SubscribeOptions options;
    private final SubscriptionEndpoint endpoint;

    public Subscription(String id, SubscribeOptions options, SubscriptionEndpoint endpoint) {
        this.id = id;
        this.options = options;
        this.endpoint = endpoint;
    }

    public String getId() {
        return id;
    }

    public SubscribeOptions getOptions() {
        return options;
    }

    public void updateOptions(SubscribeOptions opts) {
        this.options = opts;
    }

    public SubscriptionEndpoint getEndpoint() {
        return endpoint;
    }

    @Override
    public int hashCode() {
        return Objects.hashCode(
            this.id, this.options, this.endpoint);
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final Subscription other = (Subscription) obj;
        return Objects.equal(this.id, other.id)
            && Objects.equal(this.options, other.options)
            && Objects.equal(this.endpoint, other.endpoint);
    }

}
